#!/bin/sh

# Name:		Scrot
# Summary:	Screen-shot capture using Imlib 2
# Version: 	0.8
# Copyright: 	BSD
# Source: 	http://www.linuxbrit.co.uk/downloads/scrot-0.8.tar.gz
# Url: 		http://www.linuxbrit.co.uk
# Packager:	Markus Muttilainen <stillborn.zenwalk@gmail.com>


NAME=scrot
VERSION=${VERSION:-0.8}
RELEASE=${RELEASE:-64.1}
ARCH=${ARCH:-i486}
CPU=${CPU:-i686}

(

CWD="`pwd`"
TMP=${TMP:-/tmp}
ROOT=${ROOT:-$TMP/package-$NAME}

# Check if running with root priviledges
if [ "`id -u`" != "0" ]; then
	echo "Need to be root to build this package"
	exit 1
fi

cd $TMP
rm -rf $NAME-$VERSION
tar xf $CWD/$NAME-$VERSION.tar.gz || exit $?

cd $NAME-$VERSION

chown -R root.root .
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;

export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
./configure --prefix=/usr --sysconfdir=/etc --localstatedir=/var \
	--mandir=/usr/man || exit $?

make || exit $?

rm -rf $ROOT
mkdir -p $ROOT
make install DESTDIR=$ROOT

# Copy docs into the package
mkdir -p $ROOT/usr/doc/$NAME-$VERSION
cp -a AUTHORS README ChangeLog TODO \
	$ROOT/usr/doc/$NAME-$VERSION 2> /dev/null

# Remove redundant docs
rm -rf $ROOT/usr/doc/$NAME 2>/dev/null

# Strip debug info from binaries
(
  cd $ROOT ;
  find . -print0 | xargs -0 file | grep "executable" | grep ELF | cut -d : -f 1 | xargs strip --strip-unneeded ;
  find . -print0 | xargs -0 file | grep "shared object" | grep ELF | cut -d : -f 1 | xargs strip --strip-unneeded ;
  find . -print0 | xargs -0 file | grep "ar archive" | cut -d : -f 1 | xargs strip --strip-unneeded ; 
)

# Compress man pages
gzip -9 $ROOT/usr/man/man?/*

# Write out the slack-desc file
mkdir -p $ROOT/install
cat << EOF > $ROOT/install/slack-desc
scrot: Screen-shot capture using Imlib 2
scrot:
scrot: A nice and straightforward screen capture utility implementing
scrot: the dynamic loaders of imlib2.
scrot:
scrot:
scrot:
scrot:
scrot:
scrot:
scrot:
EOF

# Copy this build script into the package
mkdir -p $ROOT/usr/src/$NAME-$VERSION
cp $CWD/build-$NAME.sh $ROOT/usr/src/$NAME-$VERSION/

# Finally build the package, checksum and dependencies files
cd $ROOT 
makepkg -l y -c n $CWD/$NAME-$VERSION-$ARCH-$RELEASE.txz

cd $CWD
echo "Generating md5 checksum"
md5sum $NAME-$VERSION-$ARCH-$RELEASE.txz > $NAME-$VERSION-$ARCH-$RELEASE.md5

echo "Generating dependencies file"
depfinder  $NAME-$VERSION-$ARCH-$RELEASE.txz > $NAME-$VERSION-$ARCH-$RELEASE.dep

# Clean up all the mess
if [ "$1" == "cleanup" ]; then
  rm -rf $TMP/$NAME-$VERSION
  rm -rf $ROOT
fi
) 2>&1 | tee $NAME-$VERSION-build.txt
